@@ -35,7 +35,8 @@ protected slots:
 private:
     Phonon::MediaObject *m_mediaObject_tor;
     Phonon::MediaObject *m_mediaObject_pfeife;
-    Phonon::AudioOutput *m_audioOutput;
+    Phonon::AudioOutput *m_audioOutput_tor;
+    Phonon::AudioOutput *m_audioOutput_pfeife;
 
     MatchDayBackend* m_backend;
     MatchDayModel*   m_datamodel;
